==> eewiki-0.6.tar.gz: eewiki/src/org/j69/eewiki/action/EditForm.java <==
/*
 * ====================================================================
 *
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution, if
 *    any, must include the following acknowlegement:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowlegement may appear in the software itself,
 *    if and wherever such third-party acknowlegements normally appear.
 *
 * 4. The names "The Jakarta Project", "Struts", and "Apache Software
 *    Foundation" must not be used to endorse or promote products derived
 *    from this software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache"
 *    nor may "Apache" appear in their names without prior written
 *    permission of the Apache Group.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.j69.eewiki.action;

import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;
import org.j69.eewiki.util.CacheConfig;

/**
 * EditFor.java created by EasyStruts - XsltGen.
 * http://easystruts.sf.net
 * created on 05-22-2003
 *
 * XDoclet definition:
 * @struts:form name="EditForm"
 */
public class EditForm extends ActionForm {

	// コンフィグ
	private final static CacheConfig config_ = CacheConfig.getInstance( );

    // --------------------------------------------------------- Instance Variables

    /** password property */
    private String password;

    /** cmd property */
    private String cmd;

    /** notimestamp property */
    private boolean notimestamp;

    /** notimestamp property */
    private boolean noformat;

    /** content property */
    private String content;

    /** touchtime property */
    private String touchtime;

    /** pid property */
    private String pid;

    /** action property */
    private String action;

	/** pageowner property */
	private String pageowner;

    // --------------------------------------------------------- Methods

    /**
     * Method validate
     * @param ActionMapping mapping
     * @param HttpServletRequest request
     * @return ActionErrors
     */
    public ActionErrors validate(
        ActionMapping mapping,
        HttpServletRequest request) {

        throw new UnsupportedOperationException("Generated method 'validate(...)' not implemented.");
    }

    /**
     * Method reset
     * @param ActionMapping mapping
     * @param HttpServletRequest request
     */
    public void reset(ActionMapping mapping, HttpServletRequest request) {
        password = "";
        cmd = "";
        notimestamp = false;
        content = "";
        touchtime = "";
        pid = "";
        action = "";
    }

    /**
     * Returns the password.
     * @return String
     */
    public String getPassword() {
        return password;
    }

    /**
     * Set the password.
     * @param password The password to set
     */
    public void setPassword(String password) {
        this.password = password;
    }

    /**
     * Returns the cmd.
     * @return String
     */
    public String getCmd() {
        return cmd;
    }

    /**
     * Set the cmd.
     * @param cmd The cmd to set
     */
    public void setCmd(String cmd) {
        this.cmd = cmd;
    }

    /**
     * Returns the notimestamp.
     * @return String
     */
    public boolean getNotimestamp() {
        return notimestamp;
    }

    /**
     * Set the notimestamp.
     * @param notimestamp The notimestamp to set
     */
    public void setNotimestamp(boolean notimestamp) {
        this.notimestamp = notimestamp;
    }

    /**
     * Returns the noformat.
     * @return String
     */
    public boolean getNoformat() {
        return noformat;
    }

    /**
     * Set the noformat.
     * @param noformat The noformat to set
     */
    public void setNoformat(boolean noformat) {
        this.noformat = noformat;
    }

    /**
     * Returns the content.
     * @return String
     */
    public String getContent() {
        return content;
    }

    /**
     * Set the content.
     * @param content The content to set
     */
    public void setContent(String content) {
        this.content = content;
    }

    /**
     * Returns the touchtime.
     * @return String
     */
    public String getTouchtime() {
        return touchtime;
    }

    /**
     * Set the touchtime.
     * @param touchtime The touchtime to set
     */
    public void setTouchtime(String touchtime) {
        this.touchtime = touchtime;
    }

    /**
     * Returns the pid.
     * @return String
     */
    public String getPid() {
        return pid;
    }

    /**
     * Set the pid.
     * @param pid The pid to set
     */
    public void setPid(String pid) {
        this.pid = pid;
    }

    /**
     * Returns the action.
     * @return String
     */
    public String getAction()
    {
        return action;
    }

    /**
     * Set the action.
     * @param action The action to set
     */
    public void setAction(String action)
    {
        this.action = action;
    }

	/**
	 * @return
	 */
	public String getPageowner() {
		pageowner = config_.getConfig("define.default,pageowner");
		return pageowner;
	}

	/**
	 * @param string
	 */
	public void setPageowner(String pageowner) {
		this.pageowner = pageowner;
	}

	/**
	 * @return
	 */
	public String getEditPageowner() {
		return pageowner;
	}

}

==> eewiki-0.9.tar.gz: eewiki/src/org/j69/eewiki/action/EditForm.java <==
package org.j69.eewiki.action;

import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMapping;
import org.j69.eewiki.util.CacheConfig;

/**
 * EditFor.java created by EasyStruts - XsltGen.
 * http://easystruts.sf.net
 * created on 05-22-2003
 *
 * XDoclet definition:
 * @struts:form name="EditForm"
 */
public class EditForm extends ActionForm {

    // --------------------------------------------------------- Instance Variables

    /** password property */
    private String password;

    /** cmd property */
    private String cmd;

    /** notimestamp property */
    private boolean notimestamp;

    /** notimestamp property */
    private boolean noformat;

    /** content property */
    private String content;

    /** touchtime property */
    private String touchtime;

    /** pid property */
    private String pid;

    /** action property */
    private String action;

	/** pageowner property */
	private String pageowner = "";

    // --------------------------------------------------------- Methods

    /**
     * Method validate
     * @param ActionMapping mapping
     * @param HttpServletRequest request
     * @return ActionErrors
     */
    public ActionErrors validate(
        ActionMapping mapping,
        HttpServletRequest request) {

        throw new UnsupportedOperationException("Generated method 'validate(...)' not implemented.");
    }

    /**
     * Method reset
     * @param ActionMapping mapping
     * @param HttpServletRequest request
     */
    public void reset(ActionMapping mapping, HttpServletRequest request) {
        password = "";
        cmd = "";
        notimestamp = false;
        content = "";
        touchtime = "";
        pid = "";
        action = "";
    }

    /**
     * Returns the password.
     * @return String
     */
    public String getPassword() {
        return password;
    }

    /**
     * Set the password.
     * @param password The password to set
     */
    public void setPassword(String password) {
        this.password = password;
    }

    /**
     * Returns the cmd.
     * @return String
     */
    public String getCmd() {
        return cmd;
    }

    /**
     * Set the cmd.
     * @param cmd The cmd to set
     */
    public void setCmd(String cmd) {
        this.cmd = cmd;
    }

    /**
     * Returns the notimestamp.
     * @return String
     */
    public boolean getNotimestamp() {
        return notimestamp;
    }

    /**
     * Set the notimestamp.
     * @param notimestamp The notimestamp to set
     */
    public void setNotimestamp(boolean notimestamp) {
        this.notimestamp = notimestamp;
    }

    /**
     * Returns the noformat.
     * @return String
     */
    public boolean getNoformat() {
        return noformat;
    }

    /**
     * Set the noformat.
     * @param noformat The noformat to set
     */
    public void setNoformat(boolean noformat) {
        this.noformat = noformat;
    }

    /**
     * Returns the content.
     * @return String
     */
    public String getContent() {
        return content;
    }

    /**
     * Set the content.
     * @param content The content to set
     */
    public void setContent(String content) {
        this.content = content;
    }

    /**
     * Returns the touchtime.
     * @return String
     */
    public String getTouchtime() {
        return touchtime;
    }

    /**
     * Set the touchtime.
     * @param touchtime The touchtime to set
     */
    public void setTouchtime(String touchtime) {
        this.touchtime = touchtime;
    }

    /**
     * Returns the pid.
     * @return String
     */
    public String getPid() {
        return pid;
    }

    /**
     * Set the pid.
     * @param pid The pid to set
     */
    public void setPid(String pid) {
        this.pid = pid;
    }

    /**
     * Returns the action.
     * @return String
     */
    public String getAction()
    {
        return action;
    }

    /**
     * Set the action.
     * @param action The action to set
     */
    public void setAction(String action)
    {
        this.action = action;
    }

	/**
	 * @return
	 */
	public String getPageowner() {
		CacheConfig config_ = CacheConfig.getInstance( );
		pageowner = config_.getConfig("define.default,pageowner");
		return pageowner;
	}

	/**
	 * @param string
	 */
	public void setPageowner(String pageowner) {
		this.pageowner = pageowner;
	}

	/**
	 * @return
	 */
	public String getEditPageowner() {
		return pageowner;
	}

}
